---
name: Documentation Fix
about: Create a report to help us improve the documentation of hyppo
label: documentation

---

<!--
Thank you for taking the time to file a bug report.
Please fill in the fields below, deleting the sections that
don't apply to your issue. You can view the final output
by clicking the preview button above.
Note: This is a comment, and won't appear in the output.
-->

My issue is about ...

#### Snapshot of documentation error:
<!--
Post an image of the documentation issue
-->

#### Additional context
